@@ -2,16 +2,16 @@ import itertools
 from typing import List, Any
 import torch
 import pickle
-from stdvae import StandardVAE
-from mulvae import MultipleVAE
-from utils.models.learning_utils import make_train_step, early_stopping
+from .stdvae import StandardVAE
+from .mulvae import MultipleVAE
+from .utils.models.learning_utils import make_train_step, early_stopping
 import os
 import pandas as pd
 
 # Global variables which translate the names into the corresponding functions and objects
 activation_fn_dict = {'tanh': torch.nn.Tanh, 'relu': torch.nn.ReLU, 'sigmoid': torch.nn.Sigmoid,
                       'leaky relu': torch.nn.LeakyReLU}
-optimizers_dict = {'adam': torch.optim.Adam, 'Adadelta': torch.optim.Adadelta, 'Adagrad': torch.optim.adagrad}
+optimizers_dict = {'adam': torch.optim.Adam, 'Adadelta': torch.optim.Adadelta, 'Adagrad': torch.optim.Adagrad}
 
 
 class Data_inegrator:
